Bivariate colormaps now fully span the intended range of colors
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Bivariate colormaps generated by ``SegmentedBivarColormap`` (e.g., ``BiOrangeBlue``)
from a set of input colors now fully span that range of colors. There had been a bug
with the numerical interpolation such that the colormap did not actually include the
first or last colors.
